/*==============================================================================
FICHA: Indicador N02 - DL 1153 2023
ELABORACION: OGTI/ OGEI - MINSA - JL
==============================================================================*/
use BD_HISINDICADORES
go

--***************************************************
--				BASES DE DATOS.
--***************************************************
--HIS MINSA 
select id_cita
	, convert(date,periodo) fecha_atencion
	, convert(int,aniomes) aniomes
	, num_doc
	, id_tipitem tipo_dx
	, cod_item  
	, valor_lab
into #his_minsa
from BD_BACKUP_OGEI.dbo.MEF_TramaHisMinsa_202211_20221220 (nolock)
where cod_item in (
					'90712','90713',				--Antipolio
					'90723',						--Pentavalente
					'90681',						--Rotavirus
					'90670',						--Neumococo
					'99381',						--Cred
					'85018',						--Dosaje
					'D500','D508','D509','D649',	--Anemia
					'99199.17','u310','99199.19',	--Suplementacion
					'P073','P071','P0711','P0712'   --BPN y prematuridad 
				  )
and id_tipo_doc in (1,6) and sw=1

--PADRON NOMINAL
select distinct case when nu_dni_menor is null or nu_dni_menor in ('','null') then nu_cnv	
				else nu_dni_menor end num_doc,
				co_ubigeo_inei ubigeo,
				ti_seguro_menor seguro,
				convert(date,fe_nac_menor) fecha_nac
into #padron_nominal
from BD_BACKUP_OGEI.dbo.MEF_TramaPadronNominal_202211_20221220 (nolock)
where convert(int,ti_doc_identidad) in (1,3)
and (sw_pn=1 or sw_cnv=1) -- Validacion Dni o CNV


--***************************************************
--					SINTAXIS
--***************************************************
create table #tabla_reporte
(
num_doc nvarchar(10),
fecha_nac date,
ubigeo int,
seguro int,
edad_dias int,
fecha_corte date,
ao int,
mes int,
den int,
num int,
num_vac int,
num_polio int,
fecha_polio1 date,
fecha_polio2 date,
fecha_polio3 date,
num_penta int,
fecha_penta1 date,
fecha_penta2 date,
fecha_penta3 date,
num_rota int,
fecha_rota1 date,
fecha_rota2 date,
num_neumo int,
fecha_neumo1 date,
fecha_neumo2 date, 
num_cred int,
fecha_cred1 date,
fecha_cred2 date,
fecha_cred3 date,
fecha_cred4 date,
fecha_cred5 date,
fecha_cred6 date,
fecha_cred7 date,
fecha_cred8 date,
fecha_cred9 date,
fecha_cred10 date,
fecha_cred11 date,
num_dosaje int,
fecha_dosaje date,
num_suple int
) 

declare @mes_inicio int,
		@mes_eval int,
		@ao int ,
		@fec_eval date

set @mes_inicio=1 --<========= Mes inicio
set @mes_eval=11 --<=========== Mes de evaluacin
set @ao=2022 --<============= Ao de evaluacin 

while @mes_inicio<=@mes_eval
begin

set @fec_eval=try_convert(date,try_convert(varchar(4),@ao)+'-'+right('00'+try_convert(varchar(2),@mes_inicio),2)+'-'+right('00'+try_convert(varchar(2),1),2))

--%%%%%%%%%%%%%%%%
--  DENOMINADOR
--%%%%%%%%%%%%%%%%

-- 1.Suma de DNI o CNVs de nios que menores 364 das en el mes de evaluacin registrados en el Padrn Nominal con DNI o CNVs 
select distinct num_doc, 
				fecha_nac,
				ubigeo,
				seguro,
				datediff(dd,fecha_nac,eomonth(@fec_eval)) edad_dias,
				eomonth(@fec_eval) fecha_corte
into #padron_den
from #padron_nominal
where (eomonth(@fec_eval) between fecha_nac and dateadd(dd,364,fecha_nac) )
and year(fecha_nac)=@ao														---Partos realizados en el ao.

--%%%%%%%%%%%%%%%%
-- NUMERADOR
--%%%%%%%%%%%%%%%%

--========================================
--			VACUNAS
--=======================================

	--1.1. Vacuna Antipolio. 
			--Dosis1 
			select a.*, b.fecha_atencion fecha_polio1
			into #num_polio1
			from #padron_den a
			inner join #his_minsa b on a.num_doc=b.num_doc
			where b.cod_item in ('90712','90713')
			and (b.fecha_atencion between dateadd(dd,55,fecha_nac) and dateadd(dd,119,fecha_nac))
			and b.fecha_atencion<=a.fecha_corte

			--Dosis2
			select a.*, b.fecha_atencion fecha_polio2
			into #num_polio2
			from #num_polio1 a
			inner join #his_minsa b on a.num_doc=b.num_doc
			where b.cod_item in ('90712','90713')
			and (b.fecha_atencion between dateadd(dd,30,fecha_polio1) and dateadd(dd,70,fecha_polio1))
			and b.fecha_atencion<=a.fecha_corte

			--Dosis3
			select a.*, b.fecha_atencion fecha_polio3
			into #num_polio3
			from #num_polio2 a
			inner join #his_minsa b on a.num_doc=b.num_doc
			where b.cod_item in ('90712','90713')
			and (b.fecha_atencion between dateadd(dd,30,fecha_polio2) and dateadd(dd,70,fecha_polio2))
			and b.fecha_atencion<=a.fecha_corte
		
		--Padron dosis vacunas.			
		select a.*
		, case when (a.edad_dias between 120 and 179) and b.polio1=1 then 1
			   when (a.edad_dias between 180 and 239) and b.polio1=1 and c.polio2=1 then 1
			   when a.edad_dias>=240 and b.polio1=1 and c.polio2=1 and d.polio3=1 then 1
			   when a.edad_dias<120 then 1 else 0 end num_polio
		, b.fecha_polio1, c.fecha_polio2, d.fecha_polio3
		into #padron_num_polio
		from #padron_den a
		left join (  select num_doc, fecha_nac, ubigeo, seguro, min(fecha_polio1) fecha_polio1, polio1=1
					from #num_polio1 group by num_doc, fecha_nac, ubigeo, seguro )  b on a.num_doc=b.num_doc and a.ubigeo=b.ubigeo and a.fecha_nac=b.fecha_nac and a.seguro=b.seguro
		left join ( select num_doc, fecha_nac, ubigeo, seguro, min(fecha_polio2) fecha_polio2, polio2=1
					from #num_polio2 group by num_doc, fecha_nac, ubigeo, seguro )  c on a.num_doc=c.num_doc and a.ubigeo=c.ubigeo and a.fecha_nac=c.fecha_nac and a.seguro=c.seguro
		left join ( select num_doc, fecha_nac, ubigeo, seguro, min(fecha_polio3) fecha_polio3, polio3=1
					from #num_polio3 group by num_doc, fecha_nac, ubigeo, seguro )  d on a.num_doc=d.num_doc and a.ubigeo=d.ubigeo and a.fecha_nac=d.fecha_nac and a.seguro=d.seguro

	
	--1.2. Vacuna Pentavalente. 
			--Dosis1 
			select a.*, b.fecha_atencion fecha_penta1
			into #num_penta1
			from #padron_den a
			inner join #his_minsa b on a.num_doc=b.num_doc
			where b.cod_item='90723'
			and (b.fecha_atencion between dateadd(dd,55,fecha_nac) and dateadd(dd,119,fecha_nac))
			and b.fecha_atencion<=a.fecha_corte

			--Dosis2
			select a.*, b.fecha_atencion fecha_penta2
			into #num_penta2
			from #num_penta1 a
			inner join #his_minsa b on a.num_doc=b.num_doc
			where b.cod_item='90723'
			and (b.fecha_atencion between dateadd(dd,30,fecha_penta1) and dateadd(dd,70,fecha_penta1))
			and b.fecha_atencion<=a.fecha_corte

			--Dosis3
			select a.*, b.fecha_atencion fecha_penta3
			into #num_penta3
			from #num_penta2 a
			inner join #his_minsa b on a.num_doc=b.num_doc
			where b.cod_item in ('90712','90713')
			and (b.fecha_atencion between dateadd(dd,30,fecha_penta2) and dateadd(dd,70,fecha_penta2))
			and b.fecha_atencion<=a.fecha_corte
		
		--Padron dosis vacunas.			
		select a.*
		, case when (a.edad_dias between 120 and 179) and b.penta1=1 then 1
			   when (a.edad_dias between 180 and 239) and b.penta1=1 and c.penta2=1 then 1
			   when a.edad_dias>=240 and b.penta1=1 and c.penta2=1 and d.penta3=1 then 1
			   when a.edad_dias<120 then 1 else 0 end num_penta
		, b.fecha_penta1, c.fecha_penta2, d.fecha_penta3
		into #padron_num_penta
		from #padron_den a
		left join (  select num_doc, fecha_nac, ubigeo, seguro, min(fecha_penta1) fecha_penta1, penta1=1
					from #num_penta1 group by num_doc, fecha_nac, ubigeo, seguro )  b on a.num_doc=b.num_doc and a.ubigeo=b.ubigeo and a.fecha_nac=b.fecha_nac and a.seguro=b.seguro
		left join ( select num_doc, fecha_nac, ubigeo, seguro, min(fecha_penta2) fecha_penta2, penta2=1
					from #num_penta2 group by num_doc, fecha_nac, ubigeo, seguro )  c on a.num_doc=c.num_doc and a.ubigeo=c.ubigeo and a.fecha_nac=c.fecha_nac and a.seguro=c.seguro
		left join ( select num_doc, fecha_nac, ubigeo, seguro, min(fecha_penta3) fecha_penta3, penta3=1
					from #num_penta3 group by num_doc, fecha_nac, ubigeo, seguro )  d on a.num_doc=d.num_doc and a.ubigeo=d.ubigeo and a.fecha_nac=d.fecha_nac and a.seguro=d.seguro
				

	--1.3. Vacuna Rotavirus. 
			--Dosis1 
			select a.*, b.fecha_atencion fecha_rota1
			into #num_rota1
			from #padron_den a
			inner join #his_minsa b on a.num_doc=b.num_doc
			where b.cod_item='90681'
			and (b.fecha_atencion between dateadd(dd,55,fecha_nac) and dateadd(dd,119,fecha_nac))
			and b.fecha_atencion<=a.fecha_corte

			--Dosis2
			select a.*, b.fecha_atencion fecha_rota2
			into #num_rota2
			from #num_rota1 a
			inner join #his_minsa b on a.num_doc=b.num_doc
			where b.cod_item='90681'
			and (b.fecha_atencion between dateadd(dd,30,fecha_rota1) and dateadd(dd,239,fecha_nac))
			and b.fecha_atencion<=a.fecha_corte
	
		--Padron dosis vacunas.			
		select a.*
		, case when (a.edad_dias between 120 and 239) and b.rota1=1 then 1
			   when a.edad_dias>=240 and b.rota1=1 and c.rota2=1 then 1
			   when a.edad_dias<120 then 1 else 0 end num_rota
		, b.fecha_rota1, c.fecha_rota2
		into #padron_num_rota
		from #padron_den a
		left join (  select num_doc, fecha_nac, ubigeo, seguro, min(fecha_rota1) fecha_rota1, rota1=1
					from #num_rota1 group by num_doc, fecha_nac, ubigeo, seguro )  b on a.num_doc=b.num_doc and a.ubigeo=b.ubigeo and a.fecha_nac=b.fecha_nac and a.seguro=b.seguro
		left join ( select num_doc, fecha_nac, ubigeo, seguro, min(fecha_rota2) fecha_rota2, rota2=1
					from #num_rota2 group by num_doc, fecha_nac, ubigeo, seguro )  c on a.num_doc=c.num_doc and a.ubigeo=c.ubigeo and a.fecha_nac=c.fecha_nac and a.seguro=c.seguro


	--1.4. Vacuna Neumococo. 
			--Dosis1 
			select a.*, b.fecha_atencion fecha_neumo1
			into #num_neumo1
			from #padron_den a
			inner join #his_minsa b on a.num_doc=b.num_doc
			where b.cod_item='90670'
			and (b.fecha_atencion between dateadd(dd,55,fecha_nac) and dateadd(dd,119,fecha_nac))
			and b.fecha_atencion<=a.fecha_corte

			--Dosis2
			select a.*, b.fecha_atencion fecha_neumo2
			into #num_neumo2
			from #num_neumo1 a
			inner join #his_minsa b on a.num_doc=b.num_doc
			where b.cod_item='90670'
			and (b.fecha_atencion between dateadd(dd,30,fecha_neumo1) and dateadd(dd,70,fecha_neumo1))
			and b.fecha_atencion<=a.fecha_corte
	
		--Padron dosis vacunas.			
		select a.*
		, case when (a.edad_dias between 120 and 179) and b.neumo1=1 then 1
			   when a.edad_dias>=180 and b.neumo1=1 and c.neumo2=1 then 1
			   when a.edad_dias<120 then 1 else 0 end num_neumo
		, b.fecha_neumo1, c.fecha_neumo2
		into #padron_num_neumo
		from #padron_den a
		left join (  select num_doc, fecha_nac, ubigeo, seguro, min(fecha_neumo1) fecha_neumo1, neumo1=1
					from #num_neumo1 group by num_doc, fecha_nac, ubigeo, seguro )  b on a.num_doc=b.num_doc and a.ubigeo=b.ubigeo and a.fecha_nac=b.fecha_nac and a.seguro=b.seguro
		left join ( select num_doc, fecha_nac, ubigeo, seguro, min(fecha_neumo2) fecha_neumo2, neumo2=1
					from #num_neumo2 group by num_doc, fecha_nac, ubigeo, seguro )  c on a.num_doc=c.num_doc and a.ubigeo=c.ubigeo and a.fecha_nac=c.fecha_nac and a.seguro=c.seguro


--========================================
--			CRED
--=======================================

		--1.1  CRED 1 Control
		select distinct a.num_doc, a.fecha_nac, a.ubigeo, a.seguro, a.fecha_corte, b.fecha_atencion fecha_cred1
		into #padron_cred1
		from #padron_den a
		inner join #his_minsa b on a.num_doc=b.num_doc
		where b.cod_item='99381' and ( b.fecha_atencion between dateadd(dd,29,fecha_nac) and dateadd(dd,55,fecha_nac) )
		and b.fecha_atencion<=a.fecha_corte

		--1.2  CRED 2 Control
		select distinct a.num_doc, a.fecha_nac, a.ubigeo, a.seguro, a.fecha_corte, b.fecha_atencion fecha_cred2
		into #padron_cred2
		from #padron_cred1 a
		inner join #his_minsa b on a.num_doc=b.num_doc
		where b.cod_item='99381' and ( b.fecha_atencion between dateadd(dd,28,fecha_cred1) and dateadd(dd,30,fecha_cred1) )
		and b.fecha_atencion<=a.fecha_corte

		--1.3  CRED 3 Control
		select distinct a.num_doc, a.fecha_nac, a.ubigeo, a.seguro, a.fecha_corte, b.fecha_atencion fecha_cred3
		into #padron_cred3
		from #padron_cred2 a
		inner join #his_minsa b on a.num_doc=b.num_doc
		where b.cod_item='99381' and ( b.fecha_atencion between dateadd(dd,28,fecha_cred2) and dateadd(dd,30,fecha_cred2) )
		and b.fecha_atencion<=a.fecha_corte

		--1.4  CRED 4 Control
		select distinct a.num_doc, a.fecha_nac, a.ubigeo, a.seguro, a.fecha_corte, b.fecha_atencion fecha_cred4
		into #padron_cred4
		from #padron_cred3 a
		inner join #his_minsa b on a.num_doc=b.num_doc
		where b.cod_item='99381' and ( b.fecha_atencion between dateadd(dd,28,fecha_cred3) and dateadd(dd,30,fecha_cred3) )
		and b.fecha_atencion<=a.fecha_corte

		--1.5  CRED 5 Control
		select distinct a.num_doc, a.fecha_nac, a.ubigeo, a.seguro, a.fecha_corte, b.fecha_atencion fecha_cred5
		into #padron_cred5
		from #padron_cred4 a
		inner join #his_minsa b on a.num_doc=b.num_doc
		where b.cod_item='99381' and ( b.fecha_atencion between dateadd(dd,28,fecha_cred4) and dateadd(dd,30,fecha_cred4) )
		and b.fecha_atencion<=a.fecha_corte

		--1.6  CRED 6 Control
		select distinct a.num_doc, a.fecha_nac, a.ubigeo, a.seguro, a.fecha_corte, b.fecha_atencion fecha_cred6
		into #padron_cred6
		from #padron_cred5 a
		inner join #his_minsa b on a.num_doc=b.num_doc
		where b.cod_item='99381' and ( b.fecha_atencion between dateadd(dd,28,fecha_cred5) and dateadd(dd,30,fecha_cred5) )
		and b.fecha_atencion<=a.fecha_corte

		--1.7  CRED 7 Control
		select distinct a.num_doc, a.fecha_nac, a.ubigeo, a.seguro, a.fecha_corte, b.fecha_atencion fecha_cred7
		into #padron_cred7
		from #padron_cred6 a
		inner join #his_minsa b on a.num_doc=b.num_doc
		where b.cod_item='99381' and ( b.fecha_atencion between dateadd(dd,28,fecha_cred6) and dateadd(dd,30,fecha_cred6) )
		and b.fecha_atencion<=a.fecha_corte

		--1.8  CRED 8 Control
		select distinct a.num_doc, a.fecha_nac, a.ubigeo, a.seguro, a.fecha_corte, b.fecha_atencion fecha_cred8
		into #padron_cred8
		from #padron_cred7 a
		inner join #his_minsa b on a.num_doc=b.num_doc
		where b.cod_item='99381' and ( b.fecha_atencion between dateadd(dd,28,fecha_cred7) and dateadd(dd,30,fecha_cred7) )
		and b.fecha_atencion<=a.fecha_corte

		--1.9  CRED 9 Control
		select distinct a.num_doc, a.fecha_nac, a.ubigeo, a.seguro, a.fecha_corte, b.fecha_atencion fecha_cred9
		into #padron_cred9
		from #padron_cred8 a
		inner join #his_minsa b on a.num_doc=b.num_doc
		where b.cod_item='99381' and ( b.fecha_atencion between dateadd(dd,28,fecha_cred8) and dateadd(dd,30,fecha_cred8) )
		and b.fecha_atencion<=a.fecha_corte

		--1.10  CRED 10 Control
		select distinct a.num_doc, a.fecha_nac, a.ubigeo, a.seguro, a.fecha_corte, b.fecha_atencion fecha_cred10
		into #padron_cred10
		from #padron_cred9 a
		inner join #his_minsa b on a.num_doc=b.num_doc
		where b.cod_item='99381' and ( b.fecha_atencion between dateadd(dd,28,fecha_cred9) and dateadd(dd,30,fecha_cred9) )
		and b.fecha_atencion<=a.fecha_corte

		--1.10  CRED 11 Control
		select distinct a.num_doc, a.fecha_nac, a.ubigeo, a.seguro, a.fecha_corte, b.fecha_atencion fecha_cred11
		into #padron_cred11
		from #padron_cred10 a
		inner join #his_minsa b on a.num_doc=b.num_doc
		where b.cod_item='99381' and ( b.fecha_atencion between dateadd(dd,28,fecha_cred10) and dateadd(dd,30,fecha_cred10) )
		and b.fecha_atencion<=a.fecha_corte

	--Padron CRED.
	select a.*
	, case when (a.edad_dias between 56 and 89) and b.cred1=1 then 1 
		   when (a.edad_dias between 90 and 119) and b.cred1=1 and c.cred2=1 then 1
		   when (a.edad_dias between 120 and 149) and b.cred1=1 and c.cred2=1 and d.cred3=1 then 1
		   when (a.edad_dias between 150 and 179) and b.cred1=1 and c.cred2=1 and d.cred3=1 and e.cred4=1 then 1
		   when (a.edad_dias between 180 and 209) and b.cred1=1 and c.cred2=1 and d.cred3=1 and e.cred4=1 and f.cred5=1 then 1
		   when (a.edad_dias between 210 and 239) and b.cred1=1 and c.cred2=1 and d.cred3=1 and e.cred4=1 and f.cred5=1 and g.cred6=1 then 1
		   when (a.edad_dias between 240 and 269) and b.cred1=1 and c.cred2=1 and d.cred3=1 and e.cred4=1 and f.cred5=1 and g.cred6=1 and h.cred7=1 then 1
		   when (a.edad_dias between 270 and 299) and b.cred1=1 and c.cred2=1 and d.cred3=1 and e.cred4=1 and f.cred5=1 and g.cred6=1 and h.cred7=1 and i.cred8=1 then 1
		   when (a.edad_dias between 300 and 329) and b.cred1=1 and c.cred2=1 and d.cred3=1 and e.cred4=1 and f.cred5=1 and g.cred6=1 and h.cred7=1 and i.cred8=1 and j.cred9=1 then 1
		   when (a.edad_dias between 330 and 360) and b.cred1=1 and c.cred2=1 and d.cred3=1 and e.cred4=1 and f.cred5=1 and g.cred6=1 and h.cred7=1 and i.cred8=1 and j.cred9=1 and k.cred10=1 then 1
		   when a.edad_dias>360 and b.cred1=1 and c.cred2=1 and d.cred3=1 and e.cred4=1 and f.cred5=1 and g.cred6=1 and h.cred7=1 and i.cred8=1 and j.cred9=1 and k.cred10=1 and l.cred11=1 then 1
		   when a.edad_dias<=55 then 1 else 0 end num_cred
	, b.fecha_cred1, c.fecha_cred2, d.fecha_cred3, e.fecha_cred4, f.fecha_cred5, g.fecha_cred6
	, h.fecha_cred7, i.fecha_cred8, j.fecha_cred9, k.fecha_cred10, l.fecha_cred11
	into #padron_num_cred
	from #padron_den a
	left join 
		(select ubigeo, num_doc, seguro, fecha_nac, min(fecha_cred1) fecha_cred1, cred1=1 from #padron_cred1	
		group by ubigeo, num_doc, seguro, fecha_nac) b on a.ubigeo=b.ubigeo and a.fecha_nac=b.fecha_nac and a.num_doc=b.num_doc and a.seguro=b.seguro
	left join 
		(select ubigeo, num_doc, seguro, fecha_nac, min(fecha_cred2) fecha_cred2, cred2=1 from #padron_cred2	
		group by ubigeo, num_doc, seguro, fecha_nac) c on a.ubigeo=c.ubigeo and a.fecha_nac=c.fecha_nac and a.num_doc=c.num_doc and a.seguro=c.seguro
	left join 
		(select ubigeo, num_doc, seguro, fecha_nac, min(fecha_cred3) fecha_cred3, cred3=1 from #padron_cred3
		group by ubigeo, num_doc, seguro, fecha_nac) d on a.ubigeo=d.ubigeo and a.fecha_nac=d.fecha_nac and a.num_doc=d.num_doc and a.seguro=d.seguro
	left join 
		(select ubigeo, num_doc, seguro, fecha_nac, min(fecha_cred4) fecha_cred4, cred4=1 from #padron_cred4
		group by ubigeo, num_doc, seguro, fecha_nac) e on a.ubigeo=e.ubigeo and a.fecha_nac=e.fecha_nac and a.num_doc=e.num_doc and a.seguro=e.seguro
	left join 
		(select ubigeo, num_doc, seguro, fecha_nac, min(fecha_cred5) fecha_cred5, cred5=1 from #padron_cred5
		group by ubigeo, num_doc, seguro, fecha_nac) f on a.ubigeo=f.ubigeo and a.fecha_nac=f.fecha_nac and a.num_doc=f.num_doc and a.seguro=f.seguro
	left join 
		(select ubigeo, num_doc, seguro, fecha_nac, min(fecha_cred6) fecha_cred6, cred6=1 from #padron_cred6
		group by ubigeo, num_doc, seguro, fecha_nac) g on a.ubigeo=g.ubigeo and a.fecha_nac=g.fecha_nac and a.num_doc=g.num_doc and a.seguro=g.seguro
	left join 
		(select ubigeo, num_doc, seguro, fecha_nac, min(fecha_cred7) fecha_cred7, cred7=1 from #padron_cred7
		group by ubigeo, num_doc, seguro, fecha_nac) h on a.ubigeo=h.ubigeo and a.fecha_nac=h.fecha_nac and a.num_doc=h.num_doc and a.seguro=h.seguro
	left join 
		(select ubigeo, num_doc, seguro, fecha_nac, min(fecha_cred8) fecha_cred8, cred8=1 from #padron_cred8
		group by ubigeo, num_doc, seguro, fecha_nac) i on a.ubigeo=i.ubigeo and a.fecha_nac=i.fecha_nac and a.num_doc=i.num_doc and a.seguro=i.seguro
	left join 
		(select ubigeo, num_doc, seguro, fecha_nac, min(fecha_cred9) fecha_cred9, cred9=1 from #padron_cred9
		group by ubigeo, num_doc, seguro, fecha_nac) j on a.ubigeo=j.ubigeo and a.fecha_nac=j.fecha_nac and a.num_doc=j.num_doc and a.seguro=j.seguro
	left join 
		(select ubigeo, num_doc, seguro, fecha_nac, min(fecha_cred10) fecha_cred10, cred10=1 from #padron_cred10
		group by ubigeo, num_doc, seguro, fecha_nac) k on a.ubigeo=k.ubigeo and a.fecha_nac=k.fecha_nac and a.num_doc=k.num_doc and a.seguro=k.seguro
	left join 
		(select ubigeo, num_doc, seguro, fecha_nac, min(fecha_cred11) fecha_cred11, cred11=1 from #padron_cred11
		group by ubigeo, num_doc, seguro, fecha_nac) l on a.ubigeo=l.ubigeo and a.fecha_nac=l.fecha_nac and a.num_doc=l.num_doc and a.seguro=l.seguro

--========================================
--		DOSAJE 
--=======================================

	--1.1 Dosaje 
	select a.num_doc, a.ubigeo, a.fecha_nac, a.seguro, max(b.fecha_atencion) fecha_dosaje
	into #padron_dosaje
	from #padron_den a
	inner join #his_minsa b on a.num_doc=b.num_doc
	where b.cod_item='85018' and tipo_dx='D' and ( b.fecha_atencion between dateadd(dd,170,fecha_nac) and dateadd(dd,269,fecha_nac) )
	and b.fecha_atencion<=a.fecha_corte
	group by a.num_doc, a.ubigeo, a.fecha_nac, a.seguro

	--Padron Dosaje.
	select a.*,
	case when a.edad_dias<269 then 1
		when a.edad_dias>270 and b.fecha_dosaje is not null then 1 else 0 end num_dosaje 
	, b.fecha_dosaje
	into #padron_num_dosaje
	from #padron_den a
	left join #padron_dosaje b on a.num_doc=b.num_doc and a.fecha_nac=b.fecha_nac and a.seguro=b.seguro and a.ubigeo=b.ubigeo


--========================================
--		SUPLEMENTACION
--=======================================

	-- DX Anemia 
	select distinct b.id_cita, a.num_doc, b.fecha_atencion, dx_anemia=1 
	into #dx_anemia from #padron_den a
	inner join #his_minsa b on a.num_doc=b.num_doc 
	where b.cod_item in ('D500','D508','D509','d649') and b.fecha_atencion<=a.fecha_corte

	--BPN
	select distinct a.num_doc, bpn=1
	into #bpn from #padron_den a
	inner join #his_minsa b on a.num_doc=b.num_doc 
	where b.cod_item in ('P073','P071','P0711','P0712') and b.fecha_atencion<=a.fecha_corte

	-- Fechas de atencion de suplementacion
	select a.*	, isnull(c.dx_anemia,0) dx_anemia, isnull(d.bpn,0) bpn
	into #his_atencion_suplemetancion
	from #his_minsa a
	inner join #padron_den b on a.num_doc=b.num_doc
	left join #dx_anemia c on a.fecha_atencion=c.fecha_atencion and a.id_cita=c.id_cita and a.num_doc=c.num_doc
	left join #bpn d on a.num_doc=d.num_doc
	where a.cod_item in ('99199.17','U310','99199.19')  and a.fecha_atencion<=b.fecha_corte

	-- Valores de suplementacion y por dias.
	select distinct a.num_doc, a.seguro, a.fecha_nac, a.ubigeo, a.edad_dias, b.fecha_atencion
	,iif(cod_item in ('99199.17') and valor_lab in ('SF1','SF2','SF3','SF4','SF5','SF6') and dx_anemia=0,1,0) suple_sf_prev
	,iif(cod_item in ('99199.17') and valor_lab in ('P01','P02','P03','P04','P05','P06','PO1','PO2','PO3','PO4','PO5','PO6') and dx_anemia=0,1,0) suple_po_prev
	,iif(cod_item in ('u310','99199.17') and ( valor_lab in  ('SF1','SF2','SF3','SF4','SF5','SF6') or try_convert(int,valor_lab) in (1,2,3,4,5,6) )and dx_anemia=1,1,0) suple_sf_trat
	,iif(cod_item in ('u310','99199.17') and valor_lab in ('P01','P02','P03','P04','P05','P06','PO1','PO2','PO3','PO4','PO5','PO6') and dx_anemia=1,1,0) suple_po_trat
	,iif(cod_item in ('99199.19') and try_convert(int,valor_lab) in ('1','2','3','4','5','6','7','8','9','10','11','12') and dx_anemia=0,1,0) suple_mn
	into #temp_suple from #padron_den a
	inner join #his_atencion_suplemetancion b on a.num_doc=b.num_doc
	where b.fecha_atencion<=a.fecha_corte

	--!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	-- ESQUEMA 4 MESES. 
	--!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	select num_doc, fecha_nac, seguro, ubigeo, max(iif(suple_po_prev=1,2,iif(suple_sf_prev=1,1,0))) suple4_1 into #suple4_1
	from #temp_suple where edad_dias>=131 and (datediff(dd,fecha_nac,fecha_atencion) between 110 and 130) group by num_doc, fecha_nac, seguro, ubigeo

	select num_doc, fecha_nac, seguro, ubigeo, max(iif(suple_po_prev=1,2,iif(suple_sf_prev=1,1,0))) suple4_2 into #suple4_2
	from #temp_suple where edad_dias>=180 and (datediff(dd,fecha_nac,fecha_atencion) between 131 and 179) group by num_doc, fecha_nac, seguro, ubigeo 

	select num_doc, seguro, ubigeo, fecha_nac, max(suple4) suple4 into #suple4
	from (
			select distinct a.num_doc, a.seguro, a.fecha_nac, a.ubigeo
			, case  when d.bpn=1 then 1 when a.edad_dias<=130 then 1 
					when (a.edad_dias between 131 and 179) and b.suple4_1>=1 then 1
					when a.edad_dias>=180 and isnull(b.suple4_1,0)+isnull(c.suple4_2,0)>=2 then 1 else 0 end suple4
			from #padron_den a
			left join #bpn d on a.num_doc=d.num_doc
			left join #suple4_1 b on a.num_doc=b.num_doc and a.seguro=b.seguro and a.fecha_nac=b.fecha_nac and a.ubigeo=b.ubigeo
			left join #suple4_2 c on a.num_doc=c.num_doc and a.seguro=c.seguro and a.fecha_nac=c.fecha_nac and a.ubigeo=c.ubigeo
	) as t group by num_doc, seguro, ubigeo, fecha_nac

	--!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	-- ESQUEMA 6 MESES. 
	--!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	select num_doc, seguro, fecha_nac, ubigeo, max(iif(suple_po_prev=1,3,iif( (suple_sf_prev=1 or suple_po_trat=1),2, iif( (suple_mn=1 or suple_sf_trat=1) ,1,0)))) suple6_1 into #suple6_1
	from #temp_suple where edad_dias>=210 and (datediff(dd,fecha_nac,fecha_atencion) between 170 and 209) group by num_doc, seguro, fecha_nac, ubigeo 

	select num_doc, seguro, fecha_nac, ubigeo, max(iif(suple_po_prev=1,3,iif( (suple_sf_prev=1 or suple_po_trat=1),2, iif( (suple_mn=1 or suple_sf_trat=1) ,1,0)))) suple6_2 into #suple6_2
	from #temp_suple where edad_dias>=240 and (datediff(dd,fecha_nac,fecha_atencion) between 210 and 239) group by num_doc, seguro, fecha_nac, ubigeo 

	select num_doc, seguro, fecha_nac, ubigeo, max(iif(suple_po_prev=1,3,iif( (suple_sf_prev=1 or suple_po_trat=1),2, iif( (suple_mn=1 or suple_sf_trat=1) ,1,0)))) suple6_3 into #suple6_3
	from #temp_suple where edad_dias>=270 and (datediff(dd,fecha_nac,fecha_atencion) between 240 and 269) group by num_doc, seguro, fecha_nac, ubigeo 

	select num_doc, seguro, fecha_nac, ubigeo, max(iif(suple_po_prev=1,3,iif( (suple_sf_prev=1 or suple_po_trat=1),2, iif( (suple_mn=1 or suple_sf_trat=1) ,1,0)))) suple6_4 into #suple6_4
	from #temp_suple where edad_dias>=300 and (datediff(dd,fecha_nac,fecha_atencion) between 270 and 299) group by num_doc, seguro, fecha_nac, ubigeo 

	select num_doc, seguro, fecha_nac, ubigeo, max(iif(suple_po_prev=1,3,iif( (suple_sf_prev=1 or suple_po_trat=1),2, iif( (suple_mn=1 or suple_sf_trat=1) ,1,0)))) suple6_5 into #suple6_5
	from #temp_suple where edad_dias>=330 and (datediff(dd,fecha_nac,fecha_atencion) between 300 and 329) group by num_doc, seguro, fecha_nac, ubigeo 

	select num_doc, seguro, fecha_nac, ubigeo, max(iif(suple_po_prev=1,3,iif( (suple_sf_prev=1 or suple_po_trat=1),2, iif( (suple_mn=1 or suple_sf_trat=1) ,1,0))))suple6_6 into #suple6_6
	from #temp_suple where edad_dias>=364 and (datediff(dd,fecha_nac,fecha_atencion) between 330 and 364) group by num_doc, seguro, fecha_nac, ubigeo 

	select num_doc, seguro, ubigeo, fecha_nac, max(suple6) suple6 into #suple6
	from (
			select distinct a.num_doc, a.seguro, a.ubigeo, a.fecha_nac
			, case  when a.edad_dias<=209 then 1 
					when (a.edad_dias between 210 and 239) and b.suple6_1>=1 then 1
					when (a.edad_dias between 240 and 269) and (isnull(b.suple6_1,0)+ISNULL(c.suple6_2,0))>=2 then 1
					when (a.edad_dias between 270 and 299) and (isnull(b.suple6_1,0)+ISNULL(c.suple6_2,0)+ISNULL(d.suple6_3,0))>=3 then 1
					when (a.edad_dias between 300 and 329) and (isnull(b.suple6_1,0)+ISNULL(c.suple6_2,0)+ISNULL(d.suple6_3,0)+ISNULL(e.suple6_4,0))>=4 then 1
					when (a.edad_dias between 330 and 363) and (isnull(b.suple6_1,0)+ISNULL(c.suple6_2,0)+ISNULL(d.suple6_3,0)+ISNULL(e.suple6_4,0)+ISNULL(f.suple6_5,0))>=5 then 1
					when a.edad_dias>=364 and (isnull(b.suple6_1,0)+ISNULL(c.suple6_2,0)+ISNULL(d.suple6_3,0)+ISNULL(e.suple6_4,0)+ISNULL(f.suple6_5,0)+ISNULL(g.suple6_6,0))>=6 then 1
					else 0 end suple6
			from #padron_den a
			left join #suple6_1 b on a.num_doc=b.num_doc and a.seguro=b.seguro and a.fecha_nac=b.fecha_nac and a.ubigeo=b.ubigeo
			left join #suple6_2 c on a.num_doc=c.num_doc and a.seguro=c.seguro and a.fecha_nac=c.fecha_nac and a.ubigeo=c.ubigeo
			left join #suple6_3 d on a.num_doc=d.num_doc and a.seguro=d.seguro and a.fecha_nac=d.fecha_nac and a.ubigeo=d.ubigeo
			left join #suple6_4 e on a.num_doc=e.num_doc and a.seguro=e.seguro and a.fecha_nac=e.fecha_nac and a.ubigeo=e.ubigeo
			left join #suple6_5 f on a.num_doc=f.num_doc and a.seguro=f.seguro and a.fecha_nac=f.fecha_nac and a.ubigeo=f.ubigeo
			left join #suple6_6 g on a.num_doc=g.num_doc and a.seguro=g.seguro and a.fecha_nac=g.fecha_nac and a.ubigeo=g.ubigeo
	) as t group by num_doc, seguro, ubigeo, fecha_nac


	--!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	-- ESQUEMA 
	--!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
	select num_doc, seguro, ubigeo, fecha_nac , max(suple) suple 
	into #padron_num_suplementacion
	from (
			select a.num_doc, a.seguro, a.fecha_nac, a.ubigeo
			, case when a.edad_dias<=130 then 1
				when (a.edad_dias between 131 and 209) and b.suple4=1 then 1 
				when a.edad_dias>209 and b.suple4=1 and c.suple6=1 then 1 else 0 end suple 
			from #padron_den a
			left join #suple4 b on a.num_doc=b.num_doc and a.seguro=b.seguro and a.fecha_nac=b.fecha_nac and a.ubigeo=b.ubigeo
			left join #suple6 c on a.num_doc=c.num_doc and a.seguro=c.seguro and a.fecha_nac=c.fecha_nac and a.ubigeo=c.ubigeo
	) as t group by num_doc, seguro, ubigeo, fecha_nac


--%%%%%%%%%%%%%%%%
--	INDICADOR
--%%%%%%%%%%%%%%%%
insert into #tabla_reporte
select a.*
, year(a.fecha_corte) ao, month(a.fecha_corte) mes 
, den=1
, iif(b.num_polio=1 and c.num_penta=1 and d.num_rota=1 and e.num_neumo=1 and f.num_cred=1 and g.num_dosaje=1 and h.suple=1,1,0) num
, iif(b.num_polio=1 and c.num_penta=1 and d.num_rota=1 and e.num_neumo=1,1,0) num_vac
, b.num_polio, b.fecha_polio1, b.fecha_polio2, b.fecha_polio3
, c.num_penta, c.fecha_penta1, c.fecha_penta2, c.fecha_penta3
, d.num_rota,  d.fecha_rota1,  d.fecha_rota2
, e.num_neumo, e.fecha_neumo1, e.fecha_neumo2
, f.num_cred
, f.fecha_cred1, f.fecha_cred2, f.fecha_cred3, f.fecha_cred4, f.fecha_cred5, f.fecha_cred6
, f.fecha_cred7, f.fecha_cred8, f.fecha_cred9, f.fecha_cred10, f.fecha_cred11
, g.num_dosaje, g.fecha_dosaje
, h.suple num_suple
from #padron_den a
left join #padron_num_polio b on a.num_doc=b.num_doc and a.seguro=b.seguro and a.fecha_nac=b.fecha_nac and a.ubigeo=b.ubigeo
left join #padron_num_penta c on a.num_doc=c.num_doc and a.seguro=c.seguro and a.fecha_nac=c.fecha_nac and a.ubigeo=c.ubigeo
left join #padron_num_rota  d on a.num_doc=d.num_doc and a.seguro=d.seguro and a.fecha_nac=d.fecha_nac and a.ubigeo=d.ubigeo
left join #padron_num_neumo e on a.num_doc=e.num_doc and a.seguro=e.seguro and a.fecha_nac=e.fecha_nac and a.ubigeo=e.ubigeo
left join #padron_num_cred f on a.num_doc=f.num_doc and a.seguro=f.seguro and a.fecha_nac=f.fecha_nac and a.ubigeo=f.ubigeo
left join #padron_num_dosaje g on  a.num_doc=g.num_doc and a.seguro=g.seguro and a.fecha_nac=g.fecha_nac and a.ubigeo=g.ubigeo
left join #padron_num_suplementacion h on  a.num_doc=h.num_doc and a.seguro=h.seguro and a.fecha_nac=h.fecha_nac and a.ubigeo=h.ubigeo



drop table #bpn
drop table #dx_anemia
drop table #his_atencion_suplemetancion
drop table #num_neumo1
drop table #num_neumo2
drop table #num_penta1
drop table #num_penta2
drop table #num_penta3
drop table #num_polio1
drop table #num_polio2
drop table #num_polio3
drop table #num_rota1
drop table #num_rota2
drop table #padron_cred1
drop table #padron_cred10
drop table #padron_cred11
drop table #padron_cred2
drop table #padron_cred3
drop table #padron_cred4
drop table #padron_cred5
drop table #padron_cred6
drop table #padron_cred7
drop table #padron_cred8
drop table #padron_cred9
drop table #padron_den
drop table #padron_dosaje
drop table #padron_num_cred
drop table #padron_num_dosaje
drop table #padron_num_neumo
drop table #padron_num_penta
drop table #padron_num_polio
drop table #padron_num_rota
drop table #padron_num_suplementacion
drop table #suple4
drop table #suple4_1
drop table #suple4_2
drop table #suple6
drop table #suple6_1
drop table #suple6_2
drop table #suple6_3
drop table #suple6_4
drop table #suple6_5
drop table #suple6_6
drop table #temp_suple


set @mes_inicio = @mes_inicio + 1
end

--===================
-- REPORTE
--===================
drop table BD_HISINDICADORES.dbo.DL1153_2023_CG02_pqtnio

select 
B.diris Diris, CASE 
	WHEN B.DESC_DPTO='LIMA' AND B.DESC_PROV='LIMA' THEN 'LIMA METROPOLITANA'
	WHEN B.DESC_DPTO='LIMA' AND B.DESC_PROV<>'LIMA' THEN 'LIMA PROVINCIAS'
	ELSE B.DESC_DPTO END Departamento
, B.desc_prov Provincia
, B.desc_dist Distrito
, B.Red
, BD_HISINDICADORES.dbo.fn_calcula_edadmeses(fecha_nac,fecha_corte) as edad_mes
, a.*
into BD_HISINDICADORES.dbo.DL1153_2023_CG02_pqtnio
from #tabla_reporte a
inner join BD_HISINDICADORES.dbo.Maestro_UBIGEO_20200407 b on CONVERT(int,a.ubigeo)=CONVERT(int,b.ubigeo) 

select Diris, Departamento, Provincia, Distrito, Red, ubigeo, seguro, mes, ao, edad_mes
, sum(den) den, sum(num) num
, sum(num_vac) num_vac, sum(num_cred) num_cred, sum(num_dosaje) num_dosaje, sum(num_suple) num_suple
from BD_HISINDICADORES.dbo.DL1153_2023_CG02_pqtnio
group by Diris, Departamento, Provincia, Distrito, Red, ubigeo, seguro, mes, ao, edad_mes 


drop table #his_minsa
drop table #padron_nominal
drop table #tabla_reporte
-- =)