﻿/*==============================================================================
FICHA: Indicador N°12 - DL 1153 2023
ELABORACION: OGTI/ OGEI - MINSA - JL
==============================================================================*/
use BD_HISINDICADORES
go

--***************************************************
--				BASES DE DATOS.
--***************************************************
--HIS MINSA 
select id_cita
	, convert(date,periodo) fecha_atencion
	, convert(int,renaes) renaes
	, id_tipo_doc
	, num_doc
	, id_tipedad_reg
	, edad_reg
	, id_genero
	, id_tipitem tipo_dx
	, cod_item  
	, valor_lab
into #his_minsa
from BD_BACKUP_OGEI.dbo.MEF_TramaHisMinsa_202211_20221220 (nolock)
where sw=1															--Validacion de tipo y numero de documento
and  (
	( cod_item in ('19100','19101','19102') or (cod_item between 'C500' and 'C509') )												--Cancer de mama
or  ( cod_item='47000' or (cod_item between 'c220' and 'C229') )																	--Cancer de higado
or  ( cod_item in ('43234','43600') or (cod_item between 'c160' and 'C169') )														--Cancer de Estomago 
or  ( cod_item in ('57500','58100','C530','C531','C539') )																			--Cancer de Cuello uterinoo
or  ( cod_item in ('44388','44389','C19X','C20X') or (cod_item between 'c180' and 'C189') )											--Cancer de Colon y recto
or  ( cod_item='11100' or (cod_item between 'c430' and 'C449') )																	--Cancer de piel
or  ( cod_item in ('55700','C61X') )																								--Cancer de prostata
or  ( cod_item in ('38500','c963') or (cod_item between 'c810' and 'C859') )														--Linfoma
or  ( cod_item in ('85095','85102','C901') or (cod_item between 'c910' and 'C959')	)												--Leucemia
or  ( cod_item in ('32405','32400') or (cod_item between 'c340' and 'C349')	)														--Cancer de pulmon
or  ( cod_item in ('96402','96407','96549') or (cod_item between '96409' and '96417') or (cod_item between '96420' and '96423') )	--Tratamiento
	)


--***************************************************
--					SINTAXIS
--***************************************************
declare @mes_eval int,
		@año int 

set @mes_eval=11 --<=========== Mes de evaluación
set @año=2022 --<============= Año de evaluación 

--%%%%%%%%%%%%%%%%
-- DENOOMINADOR
--%%%%%%%%%%%%%%%%
--1. Sumatoria del Total de personas identificadas con Documento de Identidad con diagnóstico de prevalente definitivo

	--1.1 Cáncer de mama
	select distinct renaes, id_tipo_doc, num_doc
	into #his_minsa_den_mama 
	from #his_minsa
	where (cod_item between 'C500' and 'C509') and tipo_dx='D' and (valor_lab is null or valor_lab='')
	and edad_reg>=18 and id_tipedad_reg='A' and id_genero='F'
	and id_cita in (select distinct id_cita from #his_minsa where cod_item in ('19100','19101','19102') and tipo_dx='D' and valor_lab='A' )
	and year(fecha_atencion)=@año and month(fecha_atencion)<=@mes_eval

	--1.2 Cáncer de hígado
	select distinct renaes, id_tipo_doc, num_doc
	into #his_minsa_den_higado
	from #his_minsa
	where (cod_item between 'c220' and 'C229') and tipo_dx='D' and (valor_lab is null or valor_lab='')
	and edad_reg>=18 and id_tipedad_reg='A'
	and id_cita in (select distinct id_cita from #his_minsa where cod_item='47000' and tipo_dx='D' and valor_lab='A' )
	and year(fecha_atencion)=@año and month(fecha_atencion)<=@mes_eval

	--1.3 Cáncer de estómago
	select distinct renaes, id_tipo_doc, num_doc
	into #his_minsa_den_estomago
	from #his_minsa
	where (cod_item between 'c160' and 'C169') and tipo_dx='D' and (valor_lab is null or valor_lab='')
	and edad_reg>=18 and id_tipedad_reg='A'
	and id_cita in (select distinct id_cita from #his_minsa where cod_item in ('43234','43600') and tipo_dx='D' and valor_lab='A' )
	and year(fecha_atencion)=@año and month(fecha_atencion)<=@mes_eval

	--1.4 Cáncer de cuello uterino
	select distinct renaes, id_tipo_doc, num_doc
	into #his_minsa_den_uterino
	from #his_minsa
	where cod_item in ('C530','C531','C539') and tipo_dx='D' and (valor_lab is null or valor_lab='')
	and edad_reg>=18 and id_tipedad_reg='A' and id_genero='F'
	and id_cita in (select distinct id_cita from #his_minsa where cod_item in ('57500','58100') and tipo_dx='D' and valor_lab='A' )
	and year(fecha_atencion)=@año and month(fecha_atencion)=@mes_eval

	--1.5 Cáncer de colon y recto
	select distinct renaes, id_tipo_doc, num_doc
	into #his_minsa_den_colon
	from #his_minsa
	where ( (cod_item between 'c160' and 'C169') or cod_item in ('C19X','C20X') ) and tipo_dx='D' and (valor_lab is null or valor_lab='')
	and edad_reg>=18 and id_tipedad_reg='A' 
	and id_cita in (select distinct id_cita from #his_minsa where cod_item in ('44388','44389') and tipo_dx='D' and valor_lab='A' )
	and year(fecha_atencion)=@año and month(fecha_atencion)<=@mes_eval

	--1.6 Cáncer de piel
	select distinct renaes, id_tipo_doc, num_doc
	into #his_minsa_den_piel
	from #his_minsa
	where (cod_item between 'C430' and 'C449')  and tipo_dx='D' and (valor_lab is null or valor_lab='')
	and edad_reg>=18 and id_tipedad_reg='A' 
	and id_cita in (select distinct id_cita from #his_minsa where cod_item='11100' and tipo_dx='D' and valor_lab='A' )
	and year(fecha_atencion)=@año and month(fecha_atencion)<=@mes_eval

	--1.7 Cáncer de prostata
	select distinct renaes, id_tipo_doc, num_doc
	into #his_minsa_den_prostata
	from #his_minsa
	where cod_item='C61X' and tipo_dx='D' and (valor_lab is null or valor_lab='')
	and edad_reg>=18 and id_tipedad_reg='A' and id_genero='M'
	and id_cita in (select distinct id_cita from #his_minsa where cod_item='55700' and tipo_dx='D' and valor_lab='A' )
	and year(fecha_atencion)=@año and month(fecha_atencion)<=@mes_eval

	--1.8 Linfoma
	select distinct renaes, id_tipo_doc, num_doc
	into #his_minsa_den_linfoma
	from #his_minsa
	where ( (cod_item between 'C810' and 'C859') or cod_item='C963') and (valor_lab is null or valor_lab='')
	and id_cita in (select distinct id_cita from #his_minsa where cod_item='38500' and tipo_dx='D' and valor_lab='A' )
	and year(fecha_atencion)=@año and month(fecha_atencion)<=@mes_eval

	--1.9 Leucemia
	select distinct renaes, id_tipo_doc, num_doc
	into #his_minsa_den_leucemia
	from #his_minsa
	where ( (cod_item between 'C910' and 'C959') or cod_item='C901') and (valor_lab is null or valor_lab='')
	and id_cita in (select distinct id_cita from #his_minsa where cod_item in ('85095','85102') and tipo_dx='D' and valor_lab='A' )
	and year(fecha_atencion)=@año and month(fecha_atencion)<=@mes_eval

	--1.10 Pulmon
	select distinct renaes, id_tipo_doc, num_doc
	into #his_minsa_den_pulmon
	from #his_minsa
	where (cod_item between 'C340' and 'C349')  and (valor_lab is null or valor_lab='')
	and edad_reg>=18 and id_tipedad_reg='A'
	and id_cita in (select distinct id_cita from #his_minsa where cod_item in ('32405','32400') and tipo_dx='D' and valor_lab='A' )
	and year(fecha_atencion)=@año and month(fecha_atencion)<=@mes_eval

	--Denominador Final.
	select distinct renaes, id_tipo_doc, num_doc into #dpcan_den
	from (
			select * from #his_minsa_den_colon
			union all select * from #his_minsa_den_estomago
			union all select * from #his_minsa_den_higado
			union all select * from #his_minsa_den_leucemia
			union all select * from #his_minsa_den_linfoma
			union all select * from #his_minsa_den_mama
			union all select * from #his_minsa_den_piel
			union all select * from #his_minsa_den_pulmon
			union all select * from #his_minsa_den_prostata
			union all select * from #his_minsa_den_uterino
	) as t
	
--%%%%%%%%%%%%%%%%
-- NUMERADOR
--%%%%%%%%%%%%%%%%

--1. Número de personas del denominador que inician tratamiento de quimioterapia y registradas en el HIS 

	--1.1 Tratamiento Quimioterapia 1. 
	select distinct renaes, id_tipo_doc, num_doc 
	into #his_minsa_tq1
	from #his_minsa
	where (cod_item between 'c500' and 'c509') and try_convert(int, valor_lab)=1  and tipo_dx='R'
	and edad_reg>=18 and id_tipedad_reg='A' and id_genero='F'
	and year(fecha_atencion)=@año and month(fecha_atencion)<=@mes_eval

	--1.2 Tratamiento Quimioterapia 2. 
	select distinct renaes, id_tipo_doc, num_doc 
	into #his_minsa_tq2
	from #his_minsa
	where cod_item  in ('C530','C531','C539') and try_convert(int, valor_lab)=1  and tipo_dx='R'
	and edad_reg>=18 and id_tipedad_reg='A' and id_genero='F'
	and year(fecha_atencion)=@año and month(fecha_atencion)<=@mes_eval

	--1.3 Tratamiento Quimioterapia 3. 
	select distinct renaes, id_tipo_doc, num_doc 
	into #his_minsa_tq3
	from #his_minsa
	where cod_item='C61X' and try_convert(int, valor_lab)=1  and tipo_dx='R'
	and edad_reg>=18 and id_tipedad_reg='A' and id_genero='M'
	and year(fecha_atencion)=@año and month(fecha_atencion)<=@mes_eval

	--1.4 Tratamiento Quimioterapia 4. 
	select distinct renaes, id_tipo_doc, num_doc 
	into #his_minsa_tq4
	from #his_minsa
	where ( (cod_item between 'c220' and 'c229') or (cod_item between 'c160' and 'c169') or (cod_item between 'c180' and 'c189') 
			or (cod_item between 'c340' and 'c349')  or (cod_item in ('c19x','c20x')) )	and try_convert(int, valor_lab)=1  and tipo_dx='R'
	and edad_reg>=18 and id_tipedad_reg='A' 
	and id_cita in (select distinct id_cita from #his_minsa 
					where ( (cod_item in ('96402','96407','96549')) or (cod_item between '96409' and '96417') or (cod_item between '96420' and '96423') ) and tipo_dx='D') 
	and year(fecha_atencion)=@año and month(fecha_atencion)<=@mes_eval

	--1.5 Tratamiento Quimioterapia 5. 
	select distinct renaes, id_tipo_doc, num_doc 
	into #his_minsa_tq5
	from #his_minsa
	where ( (cod_item between 'c810' and 'c859') or (cod_item between 'c910' and 'c959') or (cod_item in ('c963','c901')) )	
	and try_convert(int, valor_lab)=1  and tipo_dx='R'
	and id_cita in (select distinct id_cita from #his_minsa 
					where ( (cod_item in ('96402','96407','96549')) or (cod_item between '96409' and '96417') or (cod_item between '96420' and '96423') ) and tipo_dx='D') 
	and year(fecha_atencion)=@año and month(fecha_atencion)<=@mes_eval

	--Numerador Final.
	select distinct renaes, id_tipo_doc, num_doc into #dpcan_num
	from (
			select * from #his_minsa_tq1
			union all select * from #his_minsa_tq2
			union all select * from #his_minsa_tq3
			union all select * from #his_minsa_tq4
			union all select * from #his_minsa_tq5
	) as t

	select distinct a.renaes, a.id_tipo_doc, a.num_doc, num=1
	into #dpcan_num_final 
	from #dpcan_num a
	inner join #dpcan_den b on a.renaes=b.renaes and a.id_tipo_doc=b.id_tipo_doc and a.num_doc=b.num_doc


--%%%%%%%%%%%%%%%%
--	INDICADOR
--%%%%%%%%%%%%%%%%
select @año año, renaes, sum(den) den, sum(num) num
into #tabla_reporte
from (
		select a.*, den=1, isnull(b.num,0) num
		from #dpcan_den a
		left join #dpcan_num_final b on a.renaes=b.renaes and a.id_tipo_doc=b.id_tipo_doc and a.num_doc=b.num_doc 
) as t group by renaes 

drop table #dpcan_den
drop table #dpcan_num
drop table #dpcan_num_final
drop table #his_minsa_den_colon
drop table #his_minsa_den_estomago
drop table #his_minsa_den_higado
drop table #his_minsa_den_leucemia
drop table #his_minsa_den_linfoma
drop table #his_minsa_den_mama
drop table #his_minsa_den_piel
drop table #his_minsa_den_prostata
drop table #his_minsa_den_pulmon
drop table #his_minsa_den_uterino
drop table #his_minsa_tq1
drop table #his_minsa_tq2
drop table #his_minsa_tq3
drop table #his_minsa_tq4
drop table #his_minsa_tq5

--===================
-- REPORTE
--===================
drop table BD_HISINDICADORES.dbo.DL1153_2023_CG12_PersonasCancerTratamientoOncologico

select 
B.diris Diris, CASE 
	WHEN B.DESC_DPTO='LIMA' AND B.DESC_PROV='LIMA' THEN 'LIMA METROPOLITANA'
	WHEN B.DESC_DPTO='LIMA' AND B.DESC_PROV<>'LIMA' THEN 'LIMA PROVINCIAS'
	ELSE B.DESC_DPTO END Departamento
, B.desc_prov Provincia
, B.desc_dist Distrito
, B.desc_red Red
, b.desc_mred MicroRed
, b.cat_estab
, b.desc_estab eess_nombre
, a.*
into BD_HISINDICADORES.dbo.DL1153_2023_CG12_PersonasCancerTratamientoOncologico
from #tabla_reporte a
inner join BD_BACKUP_OGEI.dbo.Renaes_20221220 b on convert(int,a.renaes)=convert(int,b.COD_ESTAB)
where b.CAT_ESTAB in ('III-2','II-2','II-1','II-E','III-E','III-1') and convert(int,b.ambito)=1

select * from BD_HISINDICADORES.dbo.DL1153_2023_CG12_PersonasCancerTratamientoOncologico


drop table #his_minsa
drop table #tabla_reporte
-- =D