/*==============================================================================
FICHA: Indicador N15 - DL 1153 2023
ELABORACION: OGTI/ OGEI - MINSA - JL
==============================================================================*/
use BD_HISINDICADORES
go

--***************************************************
--				BASES DE DATOS.
--***************************************************
--HIS MINSA 
select id_cita
	, renaes
	, convert(date,periodo) fecha_atencion
	, id_tipo_doc
	, num_doc
	, fecha_registro
	, cod_item
	, valor_lab
into #his_minsa
from BD_BACKUP_OGEI.dbo.MEF_TramaHisMinsa_202211_20221220 (nolock)
where id_tipo_doc in (1,2,3,4) and sw=1
and (convert(int,edad_reg) between 12 and 17) and id_tipedad_reg='A' 
and id_genero='F'

--***************************************************
--					SINTAXIS
--***************************************************
create table #tabla_reporte
(
renaes int,
tipo_doc int,
num_doc nvarchar(15),
fecha_atencion date,
ao int,
mes int,
den int,
num int
)


declare @mes_inicio int,
		@mes_eval int,
		@ao int ,
		@fec_eval date

set @mes_inicio=1 --<========= Mes inicio
set @mes_eval=11 --<=========== Mes de evaluacin
set @ao=2022 --<============= Ao de evaluacin 

while @mes_inicio<=@mes_eval
begin

--%%%%%%%%%%%%%%%%
--  DENOMINADOR
--%%%%%%%%%%%%%%%%

--1.Adolescentes mujeres de 12 a 17 aos fueron atendidas por el establecimiento de salud por cualquier motivo de consulta.
select distinct id_cita, renaes, fecha_atencion, id_tipo_doc, num_doc, den=1
into #his_minsa_den
from #his_minsa
where year(fecha_atencion)=@ao	
and month(fecha_atencion)=@mes_inicio

	--1.1 Se excluye adolescentes gestantes
	delete from #his_minsa_den where convert(nvarchar(1),id_tipo_doc)+num_doc in (select distinct convert(nvarchar(1),id_tipo_doc)+num_doc from #his_minsa 
											where cod_item in ('Z3491','Z3492','Z3493','Z3591','Z3592','Z3593','Z359','Z349') and year(fecha_atencion)=@ao	and month(fecha_atencion)<=@mes_inicio)
	--1.2 Se excluye adolescentes con diagnstico de anemia
	delete from #his_minsa_den where convert(nvarchar(1),id_tipo_doc)+num_doc in (select distinct convert(nvarchar(1),id_tipo_doc)+num_doc from #his_minsa 
											where cod_item in ('D500','D508','D509','D649') and year(fecha_atencion)=@ao and month(fecha_atencion)<=@mes_inicio)
	--1.3 Se excluye adolescentes que acuden solo por vacunas Covid
	delete from #his_minsa_den where id_cita in (select distinct id_cita from #his_minsa 
											where cod_item in ('90749.01','90749.02') and year(fecha_atencion)=@ao and month(fecha_atencion)=@mes_inicio)
	--1.4 Se excluye atendidas en Centros Comunitarios de Salud Mental.
	delete from #his_minsa_den where renaes in (select distinct renaes from BD_HISINDICADORES.dbo.Renaes_CSMC_2022)

--%%%%%%%%%%%%%%%%
-- NUMERADOR
--%%%%%%%%%%%%%%%%

--1.Adolescentes del denominador, que recibieron preventivamente suplemento de hierro ms cido flico
select distinct id_cita, renaes, fecha_atencion, id_tipo_doc, num_doc, num=1
into #his_minsa_num
from #his_minsa
where year(fecha_atencion)=@ao	
and month(fecha_atencion)=@mes_inicio
and cod_item='99199.26' and valor_lab='TA'

--%%%%%%%%%%%%%%%%
--	INDICADOR
--%%%%%%%%%%%%%%%%
insert into #tabla_reporte
select distinct a.renaes, a.id_tipo_doc, a.num_doc, a.fecha_atencion, year(a.fecha_atencion) ao, month(a.fecha_atencion) mes, a.den, isnull(b.num,0) num
from #his_minsa_den a
left join #his_minsa_num b on a.id_cita=b.id_cita and a.renaes=b.renaes and a.fecha_atencion=b.fecha_atencion and a.id_tipo_doc=b.id_tipo_doc and a.num_doc=b.num_doc

drop table #his_minsa_den
drop table #his_minsa_num

set @mes_inicio = @mes_inicio + 1
end

--===================
-- REPORTE
--===================
drop table BD_HISINDICADORES.dbo.DL1153_2023_CG15_SupleAdoslecente

select 
B.diris Diris, CASE 
	WHEN B.DESC_DPTO='LIMA' AND B.DESC_PROV='LIMA' THEN 'LIMA METROPOLITANA'
	WHEN B.DESC_DPTO='LIMA' AND B.DESC_PROV<>'LIMA' THEN 'LIMA PROVINCIAS'
	ELSE B.DESC_DPTO END Departamento
, B.desc_prov Provincia
, B.desc_dist Distrito
, B.desc_red Red
, b.desc_mred MicroRed
, b.cat_estab
, b.desc_estab eess_nombre
, a.*
into BD_HISINDICADORES.dbo.DL1153_2023_CG15_SupleAdoslecente
from  (
		select * 
		, row_number() over (partition by tipo_doc, num_doc order by num desc, fecha_atencion asc) id 
		from #tabla_reporte
) a
inner join BD_BACKUP_OGEI.dbo.Renaes_20221220 b on convert(int,a.renaes)=convert(int,b.COD_ESTAB)
where ( (b.CAT_ESTAB in ('I-1','I-2','I-3','I-4')) or (b.CAT_ESTAB in ('II-1','II-2','II-E') and b.CAMAS<=50) )
and a.id=1

select Diris, Departamento, Provincia, Distrito, Red, MicroRed, Cat_estab, eess_nombre, mes, ao 
, sum(den) den, sum(num) num 
from BD_HISINDICADORES.dbo.DL1153_2023_CG15_SupleAdoslecente
group by Diris, Departamento, Provincia, Distrito, Red, MicroRed, Cat_estab, eess_nombre, mes, ao 


drop table #his_minsa
drop table #tabla_reporte
-- =D